function z = zrp01(N,L,time,alpha)
%
% This function simulates the zero-range process with rates
%
%   g(k) = (k/k-1)^alpha
%
% on a one-dimensional torus with symmetric transitions.
%
% Input:
% N     - number of particle
% L     - number of lattice sites
% time  - vector: time(1) number of cycles,
%                 time(2) number of steps per cycle
% alpha - parameter (alpha > 2)
%
% Output:
% z     - evolution
%

% Initialize initial condition
%occ = hist(ceil(L*rand(N,1)),1:L);
occ = zeros(1,L); occ(ceil(L/2)) = N;
z = zeros(time(1)+1,L);

% Compute holding times
indices = find(occ > 1);
g = occ;
g(indices) = (occ(indices)./(occ(indices)-1)).^(alpha);

z(1,:) = occ;

for i=1:time(1)
    
    % Update within the cycle
    for j = 1:time(2)
        
        u = 2*(ceil((rand(1)-.5))-.5);
    
        x = randsample(L,1,true,g);
        y = mod(x+u,L);
        if y == 0, y = L; end
    
        occ(x) = occ(x) - 1;
        occ(y) = occ(y) + 1;
    
        if occ(x) < 2
            g(x) = occ(x);
        else
            g(x) = (occ(x)/(occ(x) - 1))^alpha;
        end
    
        if occ(y) < 2
            g(y) = occ(y);
        else
            g(y) = (occ(y)/(occ(y) - 1))^alpha;
        end
    end
    
    z(i+1,:) = occ;
end
