function z = zrp02(N,L,time,c,a)
%
% This function simulates the zero-range process with rates
%
%                         c(1), if k <= floor(a N)
%   g(0) = 0  and  g(k) = 
%                         c(2), if k >  floor(a N)
%
% on a one-dimensional torus with symmetric transitions.
%
% Input:
% N     - number of particle
% L     - number of lattice sites
% time  - vector: time(1) number of cycles,
%                 time(2) number of steps per cycle
% c     - vector of parameters
% a     - relative position of the jump, a \in (0,1).
%
% Output:
% z     - evolution
%

% Initialize initial condition
occ = hist(ceil(L*rand(N,1)),1:L);
  %occ = zeros(1,L); occ(1,1) = N;

z   = zeros(time(1)+1,L);
aN  = floor(a * N);

% Compute holding times
indices = find(occ > 0);
g = occ;
g(indices) = c(1);
indices = find(occ > aN);
g(indices) = c(2);

z(1,:) = occ;

for i = 1:time(1)
    
    % Update within the cycle
    for j = 1:time(2)
        u = 2*(ceil((rand(1)-.5))-.5);
    
        x = randsample(L,1,true,g);
        y = mod(x+u,L);
        if y == 0, y = L; end
    
        occ(x) = occ(x) - 1;
        occ(y) = occ(y) + 1;
    
        if occ(x) <= aN
            g(x) = c(1) * heaviside(occ(x)-.5);
        else
            g(x) = c(2);
        end
    
        if occ(y) <= aN
            g(y) = c(1);
        else
            g(y) = c(2);
        end
    end
    
    z(i+1,:) = occ;
end
